@@ -28,6 +28,7 @@
 
 from .resiliencytestsuite import ResiliencyTestSuite
 
+import base64
 import cookielib
 import random
 import string
@@ -63,6 +64,7 @@ class SlaprunnerTestSuite(ResiliencyTestSuite):
         300
     )
 
+
   def _connectToSlaprunner(self, resource, data=None):
     """
     Utility.
@@ -81,10 +83,8 @@ class SlaprunnerTestSuite(ResiliencyTestSuite):
 
   def _login(self):
     self.logger.debug('Logging in...')
-    self._connectToSlaprunner('doLogin', data='clogin=%s&cpwd=%s' % (
-        self.slaprunner_user,
-        self.slaprunner_password)
-    )
+    b64string = base64.encodestring('%s:%s' % (self.slaprunner_user, self.slaprunner_password))[:-1]
+    self._opener_director.addheaders = [('Authorization', 'Basic %s'%b64string)]
 
   def _retrieveInstanceLogFile(self):
     """
@@ -112,10 +112,17 @@ class SlaprunnerTestSuite(ResiliencyTestSuite):
     return data
 
   def _waitForSoftwareBuild(self):
-    while self._connectToSlaprunner(resource='slapgridResult', data='position=0&log=').find('"software": true') is not -1:
-      self.logger.info('Software release is still building. Sleeping...')
-      time.sleep(15)
-    self.logger.info('Software Release has been built / is no longer building.')
+    #while self._connectToSlaprunner(resource='slapgridResult', data='position=0&log=').find('"software": true') is not -1:
+    #  self.logger.info('Software release is still building. Sleeping...')
+    #  time.sleep(15)
+    #self.logger.info('Software Release has been built / is no longer building.')
+    try:
+      while self._connectToSlaprunner(resource='isSRReady') != "1":
+         self.logger.info('Software release is still building. Sleeping...')
+         time.sleep(15)
+    except (NotHttpOkException, urllib2.HTTPError):
+      # The nginx frontend might timeout before software release is finished.
+      self._waitForSoftwareBuild()
 
   def _buildSoftwareRelease(self):
     self.logger.info('Building the Software Release...')
@@ -199,6 +206,7 @@ class SlaprunnerTestSuite(ResiliencyTestSuite):
     self._openSoftwareRelease('helloworld')
 
     self._buildSoftwareRelease()
+    time.sleep(15)
     self._deployInstance()
 
     self.data = self._retrieveInstanceLogFile()
@@ -219,9 +227,7 @@ class SlaprunnerTestSuite(ResiliencyTestSuite):
     )
     self._login()
     self._waitForSoftwareBuild()
-    # XXX: in theory, it should be done automatically by slaprunner.
-    #      In practice, it is still too dangerous for ERP5 instances.
-    self._deployInstance()
+    time.sleep(15)
     new_data = self._retrieveInstanceLogFile()
 
     if new_data == self.data:
